==> db4o-5.0-mono.tar.gz: db4o-5.0/src/test/src/com/db4o/test/Circular2.cs <==
/* Copyright (C) 2004 - 2005  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
using System;
using System.Collections;
using com.db4o;

namespace com.db4o.test
{

	public class Circular2
	{
        Hashtable ht;
    
        public void storeOne(){
            Tester.objectContainer().configure().updateDepth(int.MaxValue);
            ht = new Hashtable();
            C2C c2c = new C2C();
            c2c.parent = this;
            ht["test"] = c2c;
        }
    
        public void testOne(){
            C2C c2c = (C2C)ht["test"];
            Tester.ensure(c2c.parent == this);
            Tester.objectContainer().configure().updateDepth(5);
        }
    
    }

    public class C2C{
        public Circular2 parent;
    }

}

==> db4o-5.5-mono.tar.gz: db4o-5.5/src/test/src/com/db4o/test/Circular2.cs <==
/* Copyright (C) 2004 - 2006  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
using System;
using System.Collections;
using com.db4o;

namespace com.db4o.test
{

	public class Circular2
	{
        Hashtable ht;
    
        public void StoreOne(){
            Tester.ObjectContainer().Configure().UpdateDepth(int.MaxValue);
            ht = new Hashtable();
            C2C c2c = new C2C();
            c2c.parent = this;
            ht["test"] = c2c;
        }
    
        public void TestOne(){
            C2C c2c = (C2C)ht["test"];
            Tester.Ensure(c2c.parent == this);
            Tester.ObjectContainer().Configure().UpdateDepth(5);
        }
    
    }

    public class C2C{
        public Circular2 parent;
    }

}
